Changelog
=========

0.3
---
#. Simplify layout and models. This introduces some backward incompatibility with 0.2.1. You may need to update your templates.
#. Vastly simplify the RESTful API.
#. PyPy and Python 3.5 compatibility.

0.2.1
-----
#. Consider the entire nested structure when computing a cache key.
#. Deepmerge now merges through nested lists.
#. Deepmerge now does automatic type conversion from a dictionary to a dictionary in a list if required.

0.2
---
#. Make it possible to override `iframe.html` for each project.
#. New UI theme.
#. Django template and RESTful API.

0.1.1
-----
#. Inevitable rename to avoid name collision.

0.1
----
#. First release.

